@@ -1,8 +1,9 @@
-from ocp_resources.utils.constants import TIMEOUT_4MINUTES
+from ocp_resources.constants import TIMEOUT_4MINUTES
+from ocp_resources.mtv import MTV
 from ocp_resources.resource import NamespacedResource
 
 
-class Host(NamespacedResource):
+class Host(NamespacedResource, MTV):
     """
     Migration Toolkit For Virtualization (MTV) Host resource.
     """
@@ -40,10 +41,11 @@ class Host(NamespacedResource):
         self.provider_namespace = provider_namespace
         self.secret_name = secret_name or f"{self.name}-secret"
         self.secret_namespace = secret_namespace or self.namespace
+        self.condition_message_ready = self.ConditionMessage.HOST_READY
 
-    def to_dict(self) -> None:
+    def to_dict(self):
         super().to_dict()
-        if not self.kind_dict and not self.yaml_file:
+        if not self.yaml_file:
             self.res.update({
                 "spec": {
                     "id": self.host_id,
